==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces.md <==
# ServiceMachineLearningStudioWorkspaces


```text
azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces
```

```text
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')
```



| Illustration | ServiceMachineLearningStudioWorkspaces | ServiceMachineLearningStudioWorkspacesCard | ServiceMachineLearningStudioWorkspacesGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces.png) | ![illustration for ServiceMachineLearningStudioWorkspaces](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces.Local.png) | ![illustration for ServiceMachineLearningStudioWorkspacesCard](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspacesCard.Local.png) | ![illustration for ServiceMachineLearningStudioWorkspacesGroup](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspacesGroup.Local.png) |




## ServiceMachineLearningStudioWorkspaces

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspaces
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspaces('ServiceMachineLearningStudioWorkspaces', 'Service Machine Learning Studio Workspaces', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspaces
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspaces('ServiceMachineLearningStudioWorkspaces', 'Service Machine Learning Studio Workspaces', 'an optional tech label')
@enduml
```

## ServiceMachineLearningStudioWorkspacesCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspacesCard
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspacesCard('ServiceMachineLearningStudioWorkspacesCard', 'Service Machine Learning Studio Workspaces Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspacesCard
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspacesCard('ServiceMachineLearningStudioWorkspacesCard', 'Service Machine Learning Studio Workspaces Card', 'an optional description')
@enduml
```

## ServiceMachineLearningStudioWorkspacesGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspacesGroup
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspacesGroup('ServiceMachineLearningStudioWorkspacesGroup', 'Service Machine Learning Studio Workspaces Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspacesGroup
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspacesGroup('ServiceMachineLearningStudioWorkspacesGroup', 'Service Machine Learning Studio Workspaces Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces.md <==
# ServiceMachineLearningStudioWorkspaces


```text
azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces
```

```text
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')
```



| Illustration | ServiceMachineLearningStudioWorkspaces | ServiceMachineLearningStudioWorkspacesCard | ServiceMachineLearningStudioWorkspacesGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces.png) | ![illustration for ServiceMachineLearningStudioWorkspaces](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces.Local.png) | ![illustration for ServiceMachineLearningStudioWorkspacesCard](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspacesCard.Local.png) | ![illustration for ServiceMachineLearningStudioWorkspacesGroup](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspacesGroup.Local.png) |




## ServiceMachineLearningStudioWorkspaces

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspaces
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspaces('ServiceMachineLearningStudioWorkspaces', 'Service Machine Learning Studio Workspaces', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspaces
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspaces('ServiceMachineLearningStudioWorkspaces', 'Service Machine Learning Studio Workspaces', 'an optional tech label')
@enduml
```

## ServiceMachineLearningStudioWorkspacesCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspacesCard
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspacesCard('ServiceMachineLearningStudioWorkspacesCard', 'Service Machine Learning Studio Workspaces Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspacesCard
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspacesCard('ServiceMachineLearningStudioWorkspacesCard', 'Service Machine Learning Studio Workspaces Card', 'an optional description')
@enduml
```

## ServiceMachineLearningStudioWorkspacesGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspacesGroup
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspacesGroup('ServiceMachineLearningStudioWorkspacesGroup', 'Service Machine Learning Studio Workspaces Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioWorkspacesGroup
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioWorkspaces')

' renders the element
ServiceMachineLearningStudioWorkspacesGroup('ServiceMachineLearningStudioWorkspacesGroup', 'Service Machine Learning Studio Workspaces Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
